@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## A real Try Catch Block Implementation Using Perl Filter - ~/lib/Nice/Try.pm
-## Version v1.1.0
+## Version v1.1.1
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2020/05/17
-## Modified 2021/06/06
+## Modified 2021/06/08
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -19,13 +19,12 @@ BEGIN
     use warnings::register;
     # XXX Only for debugging
     # use Devel::Confess;
-    use IO::File;
     use PPI;
     use Filter::Util::Call;
     use Scalar::Util ();
     use List::Util ();
     use Want ();
-    our $VERSION = 'v1.1.0';
+    our $VERSION = 'v1.1.1';
     our $ERROR;
     our( $CATCH, $DIED, $EXCEPTION, $FINALLY, $HAS_CATCH, @RETVAL, $SENTINEL, $TRY, $WANTARRAY );
 }
@@ -144,11 +143,11 @@ sub filter
     # $self->_message( 3, "Returning status '$line' with \$_ set to '$_'." );
     if( $self->{debug_file} )
     {
-        if( my $fh = IO::File->new( ">$self->{debug_file}" ) )
+        if( open( my $fh, ">$self->{debug_file}" ) )
         {
-            $fh->binmode( ':utf8' );
-            $fh->print( $_ );
-            $fh->close;
+            binmode( $fh, ':utf8' );
+            print( $fh $_ );
+            close( $fh );
         }
     }
     # filter_del();
@@ -1333,7 +1332,7 @@ sub _process_loop_breaks
             $self->_message( 5, "Found loop keyword '$content'." );
             # $e->set_content( qq{CORE::return( '__} . uc( $1 ) . qq{__' )} );
             # $e->set_content( q{$Nice::Try::BREAK='__} . uc( $1 ) . qq{__' ); return;} );
-            my $break_code = q{($Nice::Try::BREAK='} . $1 . qq{') ) && return;};
+            my $break_code = q{$Nice::Try::BREAK='} . $1 . qq{', return;};
             my $break_doc = PPI::Document->new( \$break_code, readonly => 1 );
             my $new_elem = $break_doc->first_element;
             # $self->_browse( $new_elem );
@@ -1365,7 +1364,7 @@ sub _process_loop_breaks
                 # We add our special return value. Notice that we use 'return' and not 
                 # 'CORE::return'. See below why.
                 # my $break_code = qq{return( '__} . uc( $word1 ) . qq{__' )};
-                my $break_code = q{($Nice::Try::BREAK='} . $word1 . qq{') && return};
+                my $break_code = q{$Nice::Try::BREAK='} . $word1 . qq{', return};
                 # e.g. next if( $i == 2 );
                 # next and if are both treated as 'word' by PPI
                 if( scalar( @$words ) > 1 )
@@ -1732,7 +1731,7 @@ Also since version 1.0.0, L<Nice::Try> is context aware:
     # scalar reference context
     my $name = ${$o->info};
 
-And you also have granual power in the catch block to filter which exception to handle:
+And you also have granual power in the catch block to filter which exception to handle. See more on this in L</"EXCEPTION CLASS">
 
     try
     {
@@ -1746,7 +1745,7 @@ And you also have granual power in the catch block to filter which exception to
     {
         # should reach here.
     }
-    catch( $oh_well isa("Exception") )
+    catch( $oh_well isa("Exception") ) # or you can also write catch( Exception $oh_well )
     {
         # Default using another way to filter by Exception
     }
@@ -1762,7 +1761,7 @@ And you also have granual power in the catch block to filter which exception to
 
 =head1 VERSION
 
-    v1.1.0
+    v1.1.1
 
 =head1 DESCRIPTION
 
@@ -1835,6 +1834,35 @@ Here is a list of its distinctive features:
         return( "Oh no: $funky_variable_name" );
     }
 
+=item * C<catch> can filter by exception class. For example:
+
+    try
+    {
+        die( My::Exception->new( "Not alllowed here.", { code => 401 }) );
+    }
+    catch( My::Exception $e where { $_->code == 500 })
+    {
+        print( "Oopsie\n" );
+    }
+    catch( My::Exception $e where { $_->code == 401 })
+    {
+        print( "Get away!\n" );
+    }
+    catch( My::Exception $e )
+    {
+        print( "Got an exception: $e\n" );
+    }
+    catch( $default )
+    {
+        print( "Something weird has happened: $e\n" );
+    }
+    finally
+    {
+        $dbh->disconnect;
+    }
+
+See more on this in L</"EXCEPTION CLASS">
+
 =item * C<$@> is always available too
 
 =item * You can return a value from try-catch blocks, even with embedded try-catch blocks
@@ -2199,7 +2227,7 @@ Since, try-catch block can be nested, the following would work too:
 
 =head1 EXCEPTION CLASS
 
-As mentioned above, you can use class when raising exceptions and you can filter them in a variety of way since version 1.0.7 when you catch them.
+As mentioned above, you can use class when raising exceptions and you can filter them in a variety of way when you catch them.
 
 Here are your options:
 
@@ -2209,7 +2237,7 @@ Here are your options:
 
 =item 2. catch( Exception::Class $error_variable where { $condition } ) { }
 
-Here C<$condition> could be anything that fits in a legitimate perl's block, such as:
+Here C<$condition> could be anything that fits in a legitimate perl block, such as:
 
     try
     {
@@ -2220,14 +2248,20 @@ Here C<$condition> could be anything that fits in a legitimate perl's block, suc
         # some more handling here
     }
 
-In the condition block C<$_> will always be made available and will correspond to the exception object thrown, just like C<$oopsie> in this example. C<$@> is also availble with the exception object as its value.
+In the condition block C<$_> will always be made available and will correspond to the exception object thrown, just like C<$oopsie> in this example. C<$@> is also available with the exception object as its value.
 
 =item 3. catch( $e isa Exception::Class ) { }
 
+This is a variant of the C<catch( Exception::Class $e ) {}> form
+
 =item 4. catch( $e isa('Exception::Class') ) { }
 
+A variant of the one above if you want to use single quotes.
+
 =item 5. catch( $e isa("Exception::Class") ) { }
 
+A variant of the one above if you want to use double quotes.
+
 =item 6. catch( $e isa Exception::Class where { $condition } ) { }
 
 =item 7. catch( $e isa('Exception::Class') where { $condition } ) { }
@@ -2236,7 +2270,7 @@ In the condition block C<$_> will always be made available and will correspond t
 
 =item 9. catch( $e where { $condition } ) { }
 
-This is not a class execption catching, but worse mentioning. For example:
+This is not a class exception catching, but worth mentioning. For example:
 
     try
     {
